@@ -4,8 +4,7 @@ from typing import Optional, Union
 
 import pint
 
-from robotoff.prediction.types import Prediction
-from robotoff.types import PredictionType
+from robotoff.types import Prediction, PredictionType
 from robotoff.utils import get_logger
 
 from .dataclass import OCRField, OCRRegex, OCRResult, get_match_bounding_box, get_text
@@ -169,7 +168,7 @@ def process_multi_packaging(match) -> Optional[dict]:
 
     count = match.group(1)
     value = match.group(2)
-    unit = match.group(3)
+    unit = match.group(3).lower()
 
     if unit in ("dle", "cle", "mge", "mle", "ge", "kge", "le"):
         # When the e letter often comes after the weight unit, the
